@@ -5,7 +5,7 @@ from abc import abstractmethod, ABCMeta
 import requests
 import requests.auth
 
-from napoleontoolbox.bifrost import Token, ClientCredentials, PasswordCredentials, Scope
+from napoleontoolbox.bifrost.models.auth import Token, ClientCredentials, PasswordCredentials, Scope
 from napoleontoolbox.bifrost.utils.security_headers import AuthorizationHeader, ApplicationJsonHeader
 
 
