@@ -5,7 +5,7 @@ from typing import Union
 
 import requests.auth
 
-from napoleontoolbox.bifrost import ClientCredentials, PasswordCredentials, Token
+from napoleontoolbox.bifrost.models.auth import ClientCredentials, PasswordCredentials, Token
 
 
 class AbstractHeaderTemplate(metaclass=ABCMeta):
